@@ -11,11 +11,11 @@ Flexnet::lmutil - Convenient OO-interface for Flexnet license server utility lmu
 
 =head1 VERSION
 
-Version 1.4
+Version 1.5
 
 =cut
 
-our $VERSION = '1.4';
+our $VERSION = '1.5';
 
 =head1 DESCRIPTION
 
@@ -295,6 +295,10 @@ sub lmstat {
 			
 		# vendor daemon status
 		} elsif ( my ($vendor, $state) = /^\s*(\S+?): (.*)/ ) {
+
+			# skip vendor_string line
+			next if $vendor eq 'vendor_string';
+
 			$status->{vendor}->{$vendor}->{status} = $state;
 			if ( $state =~ /^UP v([\d.]+)/ ) {
 				$status->{vendor}->{$vendor}->{ok} = 1;
